@@ -10,5 +10,8 @@ pub use random_str::{random_str, random_str_rg};
 mod swap;
 pub use swap::swap;
 
+mod drain_filter;
+pub use drain_filter::drain_filter;
+
 #[cfg(feature = "async")]
 pub mod futures;
